# Stubs for xlwt.Worksheet (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any
from .Style import XFStyle

class Worksheet:
    active_pane: int = ...
    Row: Any = ...
    Column: Any = ...
    show_zero_values: int = ...
    explicit_magn_setting: bool = ...
    visibility: int = ...
    split_position_units_are_twips: bool = ...
    row_default_height_mismatch: int = ...
    row_default_hidden: int = ...
    row_default_space_above: int = ...
    row_default_space_below: int = ...
    last_used_row: int = ...
    first_used_row: int = ...
    last_used_col: int = ...
    first_used_col: int = ...
    row_tempfile: Any = ...
    def __init__(self, sheetname: str, parent_book: Any, cell_overwrite_ok: bool = ...) -> None: ...
    def set_name(self, value: str) -> None: ...
    def get_name(self): ...
    name: str = ...
    def get_parent(self): ...
    parent: Any = ...
    def get_rows(self): ...
    rows: Any = ...
    def get_cols(self): ...
    cols: Any = ...
    def get_merged_ranges(self): ...
    merged_ranges: Any = ...
    def get_bmp_rec(self): ...
    bmp_rec: Any = ...
    def set_show_formulas(self, value: Any) -> None: ...
    def get_show_formulas(self): ...
    show_formulas: Any = ...
    def set_show_grid(self, value: Any) -> None: ...
    def get_show_grid(self): ...
    show_grid: Any = ...
    def set_show_headers(self, value: Any) -> None: ...
    def get_show_headers(self): ...
    show_headers: Any = ...
    def set_panes_frozen(self, value: Any) -> None: ...
    def get_panes_frozen(self): ...
    panes_frozen: Any = ...
    def set_auto_colour_grid(self, value: Any) -> None: ...
    def get_auto_colour_grid(self): ...
    auto_colour_grid: Any = ...
    def set_cols_right_to_left(self, value: Any) -> None: ...
    def get_cols_right_to_left(self): ...
    cols_right_to_left: Any = ...
    def set_show_outline(self, value: Any) -> None: ...
    def get_show_outline(self): ...
    show_outline: Any = ...
    def set_remove_splits(self, value: Any) -> None: ...
    def get_remove_splits(self): ...
    remove_splits: Any = ...
    def set_selected(self, value: Any) -> None: ...
    def get_selected(self): ...
    selected: Any = ...
    def set_sheet_visible(self, value: Any) -> None: ...
    def get_sheet_visible(self): ...
    sheet_visible: Any = ...
    def set_page_preview(self, value: Any) -> None: ...
    def get_page_preview(self): ...
    page_preview: Any = ...
    def set_first_visible_row(self, value: Any) -> None: ...
    def get_first_visible_row(self): ...
    first_visible_row: Any = ...
    def set_first_visible_col(self, value: Any) -> None: ...
    def get_first_visible_col(self): ...
    first_visible_col: Any = ...
    def set_grid_colour(self, value: Any) -> None: ...
    def get_grid_colour(self): ...
    grid_colour: Any = ...
    def set_preview_magn(self, value: Any) -> None: ...
    def get_preview_magn(self): ...
    preview_magn: Any = ...
    def set_normal_magn(self, value: Any) -> None: ...
    def get_normal_magn(self): ...
    normal_magn: Any = ...
    def set_scl_magn(self, value: Any) -> None: ...
    def get_scl_magn(self): ...
    scl_magn: Any = ...
    def set_vert_split_pos(self, value: Any) -> None: ...
    def get_vert_split_pos(self): ...
    vert_split_pos: Any = ...
    def set_horz_split_pos(self, value: Any) -> None: ...
    def get_horz_split_pos(self): ...
    horz_split_pos: Any = ...
    def set_vert_split_first_visible(self, value: Any) -> None: ...
    def get_vert_split_first_visible(self): ...
    vert_split_first_visible: Any = ...
    def set_horz_split_first_visible(self, value: Any) -> None: ...
    def get_horz_split_first_visible(self): ...
    horz_split_first_visible: Any = ...
    def set_show_auto_page_breaks(self, value: Any) -> None: ...
    def get_show_auto_page_breaks(self): ...
    show_auto_page_breaks: Any = ...
    def set_dialogue_sheet(self, value: Any) -> None: ...
    def get_dialogue_sheet(self): ...
    dialogue_sheet: Any = ...
    def set_auto_style_outline(self, value: Any) -> None: ...
    def get_auto_style_outline(self): ...
    auto_style_outline: Any = ...
    def set_outline_below(self, value: Any) -> None: ...
    def get_outline_below(self): ...
    outline_below: Any = ...
    def set_outline_right(self, value: Any) -> None: ...
    def get_outline_right(self): ...
    outline_right: Any = ...
    def set_fit_num_pages(self, value: Any) -> None: ...
    def get_fit_num_pages(self): ...
    fit_num_pages: Any = ...
    def set_show_row_outline(self, value: Any) -> None: ...
    def get_show_row_outline(self): ...
    show_row_outline: Any = ...
    def set_show_col_outline(self, value: Any) -> None: ...
    def get_show_col_outline(self): ...
    show_col_outline: Any = ...
    def set_alt_expr_eval(self, value: Any) -> None: ...
    def get_alt_expr_eval(self): ...
    alt_expr_eval: Any = ...
    def set_alt_formula_entries(self, value: Any) -> None: ...
    def get_alt_formula_entries(self): ...
    alt_formula_entries: Any = ...
    def set_row_default_height(self, value: Any) -> None: ...
    def get_row_default_height(self): ...
    row_default_height: Any = ...
    def set_col_default_width(self, value: Any) -> None: ...
    def get_col_default_width(self): ...
    col_default_width: Any = ...
    def set_calc_mode(self, value: Any) -> None: ...
    def get_calc_mode(self): ...
    calc_mode: Any = ...
    def set_calc_count(self, value: Any) -> None: ...
    def get_calc_count(self): ...
    calc_count: Any = ...
    def set_RC_ref_mode(self, value: Any) -> None: ...
    def get_RC_ref_mode(self): ...
    RC_ref_mode: Any = ...
    def set_iterations_on(self, value: Any) -> None: ...
    def get_iterations_on(self): ...
    iterations_on: Any = ...
    def set_delta(self, value: Any) -> None: ...
    def get_delta(self): ...
    delta: Any = ...
    def set_save_recalc(self, value: Any) -> None: ...
    def get_save_recalc(self): ...
    save_recalc: Any = ...
    def set_print_headers(self, value: Any) -> None: ...
    def get_print_headers(self): ...
    print_headers: Any = ...
    def set_print_grid(self, value: Any) -> None: ...
    def get_print_grid(self): ...
    print_grid: Any = ...
    def set_vert_page_breaks(self, value: Any) -> None: ...
    def get_vert_page_breaks(self): ...
    vert_page_breaks: Any = ...
    def set_horz_page_breaks(self, value: Any) -> None: ...
    def get_horz_page_breaks(self): ...
    horz_page_breaks: Any = ...
    def set_header_str(self, value: Any) -> None: ...
    def get_header_str(self): ...
    header_str: Any = ...
    def set_footer_str(self, value: Any) -> None: ...
    def get_footer_str(self): ...
    footer_str: Any = ...
    def set_print_centered_vert(self, value: Any) -> None: ...
    def get_print_centered_vert(self): ...
    print_centered_vert: Any = ...
    def set_print_centered_horz(self, value: Any) -> None: ...
    def get_print_centered_horz(self): ...
    print_centered_horz: Any = ...
    def set_left_margin(self, value: Any) -> None: ...
    def get_left_margin(self): ...
    left_margin: Any = ...
    def set_right_margin(self, value: Any) -> None: ...
    def get_right_margin(self): ...
    right_margin: Any = ...
    def set_top_margin(self, value: Any) -> None: ...
    def get_top_margin(self): ...
    top_margin: Any = ...
    def set_bottom_margin(self, value: Any) -> None: ...
    def get_bottom_margin(self): ...
    bottom_margin: Any = ...
    def set_paper_size_code(self, value: Any) -> None: ...
    def get_paper_size_code(self): ...
    paper_size_code: Any = ...
    def set_print_scaling(self, value: Any) -> None: ...
    def get_print_scaling(self): ...
    print_scaling: Any = ...
    def set_start_page_number(self, value: Any) -> None: ...
    def get_start_page_number(self): ...
    start_page_number: Any = ...
    def set_fit_width_to_pages(self, value: Any) -> None: ...
    def get_fit_width_to_pages(self): ...
    fit_width_to_pages: Any = ...
    def set_fit_height_to_pages(self, value: Any) -> None: ...
    def get_fit_height_to_pages(self): ...
    fit_height_to_pages: Any = ...
    def set_print_in_rows(self, value: Any) -> None: ...
    def get_print_in_rows(self): ...
    print_in_rows: Any = ...
    def set_portrait(self, value: Any) -> None: ...
    def get_portrait(self): ...
    portrait: Any = ...
    def set_print_colour(self, value: Any) -> None: ...
    def get_print_colour(self): ...
    print_colour: Any = ...
    def set_print_draft(self, value: Any) -> None: ...
    def get_print_draft(self): ...
    print_draft: Any = ...
    def set_print_notes(self, value: Any) -> None: ...
    def get_print_notes(self): ...
    print_notes: Any = ...
    def set_print_notes_at_end(self, value: Any) -> None: ...
    def get_print_notes_at_end(self): ...
    print_notes_at_end: Any = ...
    def set_print_omit_errors(self, value: Any) -> None: ...
    def get_print_omit_errors(self): ...
    print_omit_errors: Any = ...
    def set_print_hres(self, value: Any) -> None: ...
    def get_print_hres(self): ...
    print_hres: Any = ...
    def set_print_vres(self, value: Any) -> None: ...
    def get_print_vres(self): ...
    print_vres: Any = ...
    def set_header_margin(self, value: Any) -> None: ...
    def get_header_margin(self): ...
    header_margin: Any = ...
    def set_footer_margin(self, value: Any) -> None: ...
    def get_footer_margin(self): ...
    footer_margin: Any = ...
    def set_copies_num(self, value: Any) -> None: ...
    def get_copies_num(self): ...
    copies_num: Any = ...
    def set_wnd_protect(self, value: Any) -> None: ...
    def get_wnd_protect(self): ...
    wnd_protect: Any = ...
    def set_obj_protect(self, value: Any) -> None: ...
    def get_obj_protect(self): ...
    obj_protect: Any = ...
    def set_protect(self, value: Any) -> None: ...
    def get_protect(self): ...
    protect: Any = ...
    def set_scen_protect(self, value: Any) -> None: ...
    def get_scen_protect(self): ...
    scen_protect: Any = ...
    def set_password(self, value: Any) -> None: ...
    def get_password(self): ...
    password: Any = ...
    def write(self, r: int, c: int, label: str = ..., style: XFStyle = ...) -> None: ...
    def write_rich_text(self, r: Any, c: Any, rich_text_list: Any, style: Any = ...) -> None: ...
    def merge(self, r1: Any, r2: Any, c1: Any, c2: Any, style: Any = ...) -> None: ...
    def write_merge(self, r1: Any, r2: Any, c1: Any, c2: Any, label: str = ..., style: Any = ...) -> None: ...
    def insert_bitmap(self, filename: Any, row: Any, col: Any, x: int = ..., y: int = ..., scale_x: int = ..., scale_y: int = ...) -> None: ...
    def insert_bitmap_data(self, data: Any, row: Any, col: Any, x: int = ..., y: int = ..., scale_x: int = ..., scale_y: int = ...) -> None: ...
    def col(self, indx: Any): ...
    def row(self, indx: Any): ...
    def row_height(self, row: Any): ...
    def col_width(self, col: Any): ...
    def get_biff_data(self): ...
    def flush_row_data(self) -> None: ...



#!/usr/bin/env python2
# Copyright (c) 2013, Eduard Broecker
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are permitted provided that
# the following conditions are met:
#
#    Redistributions of source code must retain the above copyright notice, this list of conditions and the
#    following disclaimer.
#    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
#    following disclaimer in the documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED
# WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
# OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.

from __future__ import division
import math
from struct import *
import zipfile
import sys
sys.path.append('..')
import canmatrix.formats

import os

import glob
import string


def genString(string):
    retStr = "%c" % len(string)
    retStr += string
    return retStr


def genZeros(count):
    retStr = ""
    for i in range(count):
        retStr += "\x00"
    return retStr


def genSimulatonFile(nodes):
    # header
    retStr = "ff\xA6\x3F"
    retStr += genString("RBEI_FRAME")
    retStr += genString("CAN")
    retStr += genString("1.8.0")

    # count of nodes:
    retStr += "%c" % len(nodes)
    retStr += genZeros(4)

    # each node
    for (nodename, source) in list(nodes.items()):
        retStr += genString(source).encode('ascii')
        retStr += genString(nodename).encode('ascii')
        retStr += genZeros(10)

    # checksum
    temp = 0
    for c in retStr:
        ibyte = unpack('B', c)
        temp = (temp ^ ibyte[0])
    retStr = retStr[:-1] + "%c" % temp
    return retStr


def createNode(structNames, timedPrototypes, timedCallbacks):
    nodetemplate = """
/* This file is generated by BUSMASTER */
/* VERSION [1.1] */
/* BUSMASTER VERSION [1.8.0] */
/* PROTOCOL [CAN] */

/* Start BUSMASTER include header */
#include <Windows.h>
#include <CANIncludes.h>

/* End BUSMASTER include header */


/* Start BUSMASTER global variable */
"""

    nodetemplate2 = """
/* End BUSMASTER global variable */

/* Start BUSMASTER Function Prototype  */
"""
    return nodetemplate + structNames + nodetemplate2 + timedPrototypes + \
        "/* End BUSMASTER Function Prototype  */\n" + timedCallbacks


def genCallbacks(cycle, bId, db):
    botsch = db.frames.byId(bId).name
    callbacks = "/* Start BUSMASTER generated function - OnTimer_" + \
        botsch + "_" + str(cycle) + " */\n"
    callbacks += "void OnTimer_" + botsch + "_" + str(cycle) + "( )\n"
    callbacks += "{\n"

    canData = db.frames.byId(bId).attributes["GenMsgStartValue"][1:-2]
    dlc = math.floor(len(canData) / 2)
    callbacks += "    SendMsg(" + botsch + ");\n"
    callbacks += "\n} "
    callbacks += "/* End BUSMASTER generated function - OnTimer_" + \
        botsch + "_" + str(cycle) + " */\n\n"
    prototype = "GCC_EXTERN void GCC_EXPORT OnTimer_" + \
        botsch + "_" + str(cycle) + "( );\n"
    structNames = "STCAN_MSG " + botsch + \
        " = { " + hex(bId) + ", 0, 0, " + \
        str(math.floor(len(canData) / 2)) + ", 1,"
    for i in range(dlc):
        structNames += " 0x" + canData[i * 2:i * 2 + 2]
        if i < dlc - 1:
            structNames += ", "
    exports = "OnTimer_" + botsch + "_" + str(cycle) + "\n"

    structNames += "};\n"

    return structNames, prototype, callbacks, exports

exportTemplate = """EXPORTS
vSetEnableLoggingProcAddress
vSetDisableLoggingProcAddress
vSetWriteToLogFileProcAddress
vSetConnectProcAddress
vSetDisconnectProcAddress
vSetGoOnlineProcAddress
vSetGoOfflineProcAddress
vSetStartTimerProcAddress
vSetStopTimerProcAddress
vSetSetTimerValProcAddress
vSetEnableMsgHandlersProcAddress
vSetEnableErrorHandlersProcAddress
vSetEnableKeyHandlersProcAddress
vSetEnableDisableMsgTxProcAddress
vSetSendMsgProcAddress
vSetGetDllHandleProcAddress
vSetTraceProcAddress
vSetResetControllerProcAddress
bGetProgramVersion
vSetKeyPressed
vSetGetMessageName
vSetTimeNow
vSetGetFirstCANdbName

"""


def ticker_ecus(db, dbcname):
    nodeList = {}
    zf = zipfile.ZipFile(dbcname + '_Simulation.zip',
                         mode='w',
                         compression=zipfile.ZIP_DEFLATED,
                         )

    MyBuList = []

    for bu in db.ecus:
        if bu.name not in MyBuList:
            MyBuList.append(bu.name)  # no duplicate Nodes
        else:
            continue
        bu._cycles = {}
        for frame in db.frames:
            if bu.name in frame.transmitters:
                if frame.effective_cycle_time != 0 and "GenMsgStartValue" in frame.attributes:
                    data = frame.attributes["GenMsgStartValue"][1:-2]
                    dlc = (math.floor(len(data) / 2))
                    cycleTime = frame.effective_cycle_time
                    if float(cycleTime) > 0:
                        if cycleTime in bu._cycles:
                            bu._cycles[cycleTime].append(frame.arbitration_id.id)
                        else:
                            bu._cycles[cycleTime] = [frame.arbitration_id.id]
        nodeList[bu.name] = bu.name + ".cpp"

        timedPrototypes = ""
        timedCallbacks = ""
        structNames = ""
        exports = ""
        for cycle in bu._cycles:
            for frame in bu._cycles[cycle]:
                (tempstructNames, tempPrototypes, tempCallbacks,
                 tempExports) = genCallbacks(cycle, frame, db)
                structNames += tempstructNames
                timedPrototypes += tempPrototypes
                timedCallbacks += tempCallbacks
                exports += tempExports

        nodeString = createNode(structNames, timedPrototypes, timedCallbacks)

        zf.writestr(bu.name + ".cpp", nodeString)
        zf.writestr(bu.name + ".def", exportTemplate + exports)
    zf.writestr(dbcname + '.sim', genSimulatonFile(nodeList))
    zf.close()


def main():
    if len(sys.argv) < 3:
        sys.stderr.write('Usage: sys.argv[0] import-file export-file\n')
        sys.stderr.write('import-file: *.dbc|*.dbf|*.kcd\n')
        sys.stderr.write('export-file: somefile.zip\n')
        sys.exit(1)

    infile = sys.argv[1]
    outfile = os.path.splitext(sys.argv[2])[0]

    db = next(iter(canmatrix.formats.loadp(infile).values()))
    ticker_ecus(db, outfile)

main()



# Stubs for xlrd.timemachine (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

python_version: Any
BYTES_LITERAL: Any
UNICODE_LITERAL: Any
BYTES_ORD: Any

def fprintf(f: Any, fmt: Any, *vargs: Any) -> None: ...

EXCEL_TEXT_TYPES: Any
REPR = ascii
xrange = range
unicode: Any
ensure_unicode: Any
unichr = chr



# Hand-written stub, incomplete

from typing import Union

from lxml.etree import ElementBase, XMLParser

class ObjectifiedElement(ElementBase):
    pass

def fromstring(text: Union[bytes, str],
               parser: XMLParser = ...,
               *,
               base_url: Union[bytes, str] = ...) -> ObjectifiedElement: ...



# Stubs for xlwt.Column (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

class Column:
    width: int = ...
    hidden: int = ...
    level: int = ...
    collapse: int = ...
    user_set: int = ...
    best_fit: int = ...
    unused: int = ...
    def __init__(self, colx: Any, parent_sheet: Any) -> None: ...
    def set_width(self, width: Any) -> None: ...
    def get_width(self): ...
    def set_style(self, style: Any) -> None: ...
    def width_in_pixels(self): ...
    def get_biff_record(self): ...



# Stubs for xlwt.BIFFRecords (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional

class SharedStringTable:
    encoding: Any = ...
    def __init__(self, encoding: Any) -> None: ...
    def add_str(self, s: Any): ...
    def add_rt(self, rt: Any): ...
    def del_str(self, idx: Any) -> None: ...
    def str_index(self, s: Any): ...
    def rt_index(self, rt: Any): ...
    def get_biff_record(self): ...

class BiffRecord:
    def get_rec_header(self): ...
    def get(self): ...

class Biff8BOFRecord(BiffRecord):
    BOOK_GLOBAL: int = ...
    VB_MODULE: int = ...
    WORKSHEET: int = ...
    CHART: int = ...
    MACROSHEET: int = ...
    WORKSPACE: int = ...
    def __init__(self, rec_type: Any) -> None: ...

class InteraceHdrRecord(BiffRecord):
    def __init__(self) -> None: ...

class InteraceEndRecord(BiffRecord):
    def __init__(self) -> None: ...

class MMSRecord(BiffRecord):
    def __init__(self) -> None: ...

class WriteAccessRecord(BiffRecord):
    def __init__(self, owner: Any) -> None: ...

class DSFRecord(BiffRecord):
    def __init__(self) -> None: ...

class TabIDRecord(BiffRecord):
    def __init__(self, sheetcount: Any) -> None: ...

class FnGroupCountRecord(BiffRecord):
    def __init__(self) -> None: ...

class WindowProtectRecord(BiffRecord):
    def __init__(self, wndprotect: Any) -> None: ...

class ObjectProtectRecord(BiffRecord):
    def __init__(self, objprotect: Any) -> None: ...

class ScenProtectRecord(BiffRecord):
    def __init__(self, scenprotect: Any) -> None: ...

class ProtectRecord(BiffRecord):
    def __init__(self, protect: Any) -> None: ...

class PasswordRecord(BiffRecord):
    def passwd_hash(self, plaintext: Any): ...
    def __init__(self, passwd: str = ...) -> None: ...

class Prot4RevRecord(BiffRecord):
    def __init__(self) -> None: ...

class Prot4RevPassRecord(BiffRecord):
    def __init__(self) -> None: ...

class BackupRecord(BiffRecord):
    def __init__(self, backup: Any) -> None: ...

class HideObjRecord(BiffRecord):
    def __init__(self) -> None: ...

class RefreshAllRecord(BiffRecord):
    def __init__(self) -> None: ...

class BookBoolRecord(BiffRecord):
    def __init__(self) -> None: ...

class CountryRecord(BiffRecord):
    def __init__(self, ui_id: Any, sys_settings_id: Any) -> None: ...

class UseSelfsRecord(BiffRecord):
    def __init__(self) -> None: ...

class EOFRecord(BiffRecord):
    def __init__(self) -> None: ...

class DateModeRecord(BiffRecord):
    def __init__(self, from1904: Any) -> None: ...

class PrecisionRecord(BiffRecord):
    def __init__(self, use_real_values: Any) -> None: ...

class CodepageBiff8Record(BiffRecord):
    UTF_16: int = ...
    def __init__(self) -> None: ...

class Window1Record(BiffRecord):
    def __init__(self, hpos_twips: Any, vpos_twips: Any, width_twips: Any, height_twips: Any, flags: Any, active_sheet: Any, first_tab_index: Any, selected_tabs: Any, tab_width: Any) -> None: ...

class FontRecord(BiffRecord):
    def __init__(self, height: Any, options: Any, colour_index: Any, weight: Any, escapement: Any, underline: Any, family: Any, charset: Any, name: Any) -> None: ...

class NumberFormatRecord(BiffRecord):
    def __init__(self, idx: Any, fmtstr: Any) -> None: ...

class XFRecord(BiffRecord):
    def __init__(self, xf: Any, xftype: str = ...) -> None: ...

class StyleRecord(BiffRecord):
    def __init__(self) -> None: ...

class PaletteRecord(BiffRecord):
    def __init__(self, custom_palette: Any) -> None: ...

class BoundSheetRecord(BiffRecord):
    def __init__(self, stream_pos: Any, visibility: Any, sheetname: Any, encoding: str = ...) -> None: ...

class ContinueRecord(BiffRecord): ...
class SSTRecord(BiffRecord): ...

class ExtSSTRecord(BiffRecord):
    def __init__(self, sst_stream_pos: Any, str_placement: Any, portions_len: Any) -> None: ...

class DimensionsRecord(BiffRecord):
    def __init__(self, first_used_row: Any, last_used_row: Any, first_used_col: Any, last_used_col: Any) -> None: ...

class Window2Record(BiffRecord):
    def __init__(self, options: Any, first_visible_row: Any, first_visible_col: Any, grid_colour: Any, preview_magn: Any, normal_magn: Any, scl_magn: Any) -> None: ...
    def get(self): ...

class PanesRecord(BiffRecord):
    valid_active_pane: Any = ...
    def __init__(self, px: Any, py: Any, first_row_bottom: Any, first_col_right: Any, active_pane: Any) -> None: ...

class RowRecord(BiffRecord):
    def __init__(self, index: Any, first_col: Any, last_col: Any, height_options: Any, options: Any) -> None: ...

class LabelSSTRecord(BiffRecord):
    def __init__(self, row: Any, col: Any, xf_idx: Any, sst_idx: Any) -> None: ...

class MergedCellsRecord(BiffRecord):
    def __init__(self, merged_list: Any) -> None: ...
    def get(self): ...

class MulBlankRecord(BiffRecord):
    def __init__(self, row: Any, first_col: Any, last_col: Any, xf_index: Any) -> None: ...

class BlankRecord(BiffRecord):
    def __init__(self, row: Any, col: Any, xf_index: Any) -> None: ...

class RKRecord(BiffRecord):
    def __init__(self, row: Any, col: Any, xf_index: Any, rk_encoded: Any) -> None: ...

class NumberRecord(BiffRecord):
    def __init__(self, row: Any, col: Any, xf_index: Any, number: Any) -> None: ...

class BoolErrRecord(BiffRecord):
    def __init__(self, row: Any, col: Any, xf_index: Any, number: Any, is_error: Any) -> None: ...

class FormulaRecord(BiffRecord):
    def __init__(self, row: Any, col: Any, xf_index: Any, rpn: Any, calc_flags: int = ...) -> None: ...

class GutsRecord(BiffRecord):
    def __init__(self, row_gut_width: Any, col_gut_height: Any, row_visible_levels: Any, col_visible_levels: Any) -> None: ...

class WSBoolRecord(BiffRecord):
    def __init__(self, options: Any) -> None: ...

class ColInfoRecord(BiffRecord):
    def __init__(self, first_col: Any, last_col: Any, width: Any, xf_index: Any, options: Any, unused: Any) -> None: ...

class CalcModeRecord(BiffRecord):
    def __init__(self, calc_mode: Any) -> None: ...

class CalcCountRecord(BiffRecord):
    def __init__(self, calc_count: Any) -> None: ...

class RefModeRecord(BiffRecord):
    def __init__(self, ref_mode: Any) -> None: ...

class IterationRecord(BiffRecord):
    def __init__(self, iterations_on: Any) -> None: ...

class DeltaRecord(BiffRecord):
    def __init__(self, delta: Any) -> None: ...

class SaveRecalcRecord(BiffRecord):
    def __init__(self, recalc: Any) -> None: ...

class PrintHeadersRecord(BiffRecord):
    def __init__(self, print_headers: Any) -> None: ...

class PrintGridLinesRecord(BiffRecord):
    def __init__(self, print_grid: Any) -> None: ...

class GridSetRecord(BiffRecord):
    def __init__(self, print_grid_changed: Any) -> None: ...

class DefaultRowHeightRecord(BiffRecord):
    def __init__(self, options: Any, def_height: Any) -> None: ...

class DefColWidthRecord(BiffRecord):
    def __init__(self, def_width: Any) -> None: ...

class HorizontalPageBreaksRecord(BiffRecord):
    def __init__(self, breaks_list: Any) -> None: ...

class VerticalPageBreaksRecord(BiffRecord):
    def __init__(self, breaks_list: Any) -> None: ...

class HeaderRecord(BiffRecord):
    def __init__(self, header_str: Any) -> None: ...

class FooterRecord(BiffRecord):
    def __init__(self, footer_str: Any) -> None: ...

class HCenterRecord(BiffRecord):
    def __init__(self, is_horz_center: Any) -> None: ...

class VCenterRecord(BiffRecord):
    def __init__(self, is_vert_center: Any) -> None: ...

class LeftMarginRecord(BiffRecord):
    def __init__(self, margin: Any) -> None: ...

class RightMarginRecord(BiffRecord):
    def __init__(self, margin: Any) -> None: ...

class TopMarginRecord(BiffRecord):
    def __init__(self, margin: Any) -> None: ...

class BottomMarginRecord(BiffRecord):
    def __init__(self, margin: Any) -> None: ...

class SetupPageRecord(BiffRecord):
    def __init__(self, paper: Any, scaling: Any, start_num: Any, fit_width_to: Any, fit_height_to: Any, options: Any, hres: Any, vres: Any, header_margin: Any, footer_margin: Any, num_copies: Any) -> None: ...

class NameRecord(BiffRecord):
    def __init__(self, options: Any, keyboard_shortcut: Any, name: Any, sheet_index: Any, rpn: Any, menu_text: str = ..., desc_text: str = ..., help_text: str = ..., status_text: str = ...) -> None: ...

class ExternSheetRecord(BiffRecord):
    refs: Any = ...
    def __init__(self, refs: Any) -> None: ...
    def get(self): ...

class SupBookRecord(BiffRecord): ...

class InternalReferenceSupBookRecord(SupBookRecord):
    def __init__(self, num_sheets: Any) -> None: ...

class XcallSupBookRecord(SupBookRecord):
    def __init__(self) -> None: ...

class ExternnameRecord(BiffRecord):
    def __init__(self, options: int = ..., index: int = ..., name: Optional[Any] = ..., fmla: Optional[Any] = ...) -> None: ...



# Stubs for xlwt.antlr (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional

SKIP: int
INVALID_TYPE: int
EOF_TYPE: int
EOF: int
NULL_TREE_LOOKAHEAD: int
MIN_USER_TYPE: int
EOF_CHAR: str

def version(): ...
def error(fmt: Any, *args: Any) -> None: ...
def ifelse(cond: Any, _then: Any, _else: Any): ...
def is_string_type(x: Any): ...
def assert_string_type(x: Any) -> None: ...

class ANTLRException(Exception):
    def __init__(self, *args: Any) -> None: ...

class RecognitionException(ANTLRException):
    fileName: Any = ...
    line: int = ...
    column: int = ...
    def __init__(self, *args: Any) -> None: ...

class NoViableAltException(RecognitionException):
    token: Any = ...
    node: Any = ...
    def __init__(self, *args: Any) -> None: ...

class NoViableAltForCharException(RecognitionException):
    foundChar: Any = ...
    def __init__(self, *args: Any) -> None: ...

class SemanticException(RecognitionException):
    def __init__(self, *args: Any) -> None: ...

class MismatchedCharException(RecognitionException):
    NONE: int = ...
    CHAR: int = ...
    NOT_CHAR: int = ...
    RANGE: int = ...
    NOT_RANGE: int = ...
    SET: int = ...
    NOT_SET: int = ...
    args: Any = ...
    mismatchType: Any = ...
    foundChar: Any = ...
    expecting: Any = ...
    upper: Any = ...
    scanner: Any = ...
    set: Any = ...
    def __init__(self, *args: Any) -> None: ...
    def appendCharName(self, sb: Any, c: Any) -> None: ...

class MismatchedTokenException(RecognitionException):
    NONE: int = ...
    TOKEN: int = ...
    NOT_TOKEN: int = ...
    RANGE: int = ...
    NOT_RANGE: int = ...
    SET: int = ...
    NOT_SET: int = ...
    args: Any = ...
    tokenNames: Any = ...
    token: Any = ...
    tokenText: str = ...
    node: Any = ...
    mismatchType: Any = ...
    expecting: Any = ...
    upper: Any = ...
    fileName: Any = ...
    set: Any = ...
    def __init__(self, *args: Any) -> None: ...
    def appendTokenName(self, sb: Any, tokenType: Any) -> None: ...

class TokenStreamException(ANTLRException):
    def __init__(self, *args: Any) -> None: ...

class TokenStreamIOException(TokenStreamException):
    io: Any = ...
    def __init__(self, *args: Any) -> None: ...

class TokenStreamRecognitionException(TokenStreamException):
    recog: Any = ...
    def __init__(self, *args: Any) -> None: ...

class TokenStreamRetryException(TokenStreamException):
    def __init__(self, *args: Any) -> None: ...

class CharStreamException(ANTLRException):
    def __init__(self, *args: Any) -> None: ...

class CharStreamIOException(CharStreamException):
    io: Any = ...
    def __init__(self, *args: Any) -> None: ...

class TryAgain(Exception): ...

class Token:
    SKIP: int = ...
    INVALID_TYPE: int = ...
    EOF_TYPE: int = ...
    EOF: int = ...
    NULL_TREE_LOOKAHEAD: int = ...
    MIN_USER_TYPE: int = ...
    type: Any = ...
    text: Any = ...
    def __init__(self, **argv: Any) -> None: ...
    def isEOF(self): ...
    def getColumn(self): ...
    def getLine(self): ...
    def getFilename(self) -> None: ...
    def setFilename(self, name: Any): ...
    def getText(self): ...
    def setText(self, text: Any): ...
    def setColumn(self, column: Any): ...
    def setLine(self, line: Any): ...
    def getType(self): ...
    def setType(self, type: Any): ...
    def toString(self): ...

class CommonToken(Token):
    line: int = ...
    col: int = ...
    def __init__(self, **argv: Any) -> None: ...
    def getLine(self): ...
    def getText(self): ...
    def getColumn(self): ...
    def setLine(self, line: Any): ...
    text: Any = ...
    def setText(self, text: Any): ...
    def setColumn(self, col: Any): ...
    def toString(self): ...

class CommonHiddenStreamToken(CommonToken):
    hiddenBefore: Any = ...
    hiddenAfter: Any = ...
    def __init__(self, *args: Any) -> None: ...
    def getHiddenAfter(self): ...
    def getHiddenBefore(self): ...
    def setHiddenAfter(self, t: Any) -> None: ...
    def setHiddenBefore(self, t: Any) -> None: ...

class Queue:
    buffer: Any = ...
    def __init__(self) -> None: ...
    def append(self, item: Any) -> None: ...
    def elementAt(self, index: Any): ...
    def reset(self) -> None: ...
    def removeFirst(self) -> None: ...
    def length(self): ...

class InputBuffer:
    nMarkers: int = ...
    markerOffset: int = ...
    numToConsume: int = ...
    queue: Any = ...
    def __init__(self) -> None: ...
    def commit(self) -> None: ...
    def consume(self) -> None: ...
    def getLAChars(self): ...
    def getMarkedChars(self): ...
    def isMarked(self): ...
    def fill(self, k: Any) -> None: ...
    def LA(self, k: Any): ...
    def mark(self): ...
    def rewind(self, mark: Any) -> None: ...
    def reset(self) -> None: ...
    def syncConsume(self) -> None: ...

class CharBuffer(InputBuffer):
    input: Any = ...
    def __init__(self, reader: Any) -> None: ...
    def fill(self, amount: Any) -> None: ...

class LexerSharedInputState:
    input: Any = ...
    column: int = ...
    line: int = ...
    tokenStartColumn: int = ...
    tokenStartLine: int = ...
    guessing: int = ...
    filename: Any = ...
    def __init__(self, ibuf: Any) -> None: ...
    def reset(self) -> None: ...
    def LA(self, k: Any): ...

class TokenStream:
    def nextToken(self) -> None: ...
    def __iter__(self): ...

class TokenStreamIterator:
    inst: Any = ...
    def __init__(self, inst: Any) -> None: ...
    def next(self): ...

class TokenStreamSelector(TokenStream):
    def __init__(self) -> None: ...
    def addInputStream(self, stream: Any, key: Any) -> None: ...
    def getCurrentStream(self): ...
    def getStream(self, sname: Any): ...
    def nextToken(self): ...
    def pop(self): ...
    def push(self, arg: Any) -> None: ...
    def retry(self) -> None: ...
    def select(self, arg: Any) -> None: ...

class TokenStreamBasicFilter(TokenStream):
    input: Any = ...
    discardMask: Any = ...
    def __init__(self, input: Any) -> None: ...
    discardMark: Any = ...
    def discard(self, arg: Any) -> None: ...
    def nextToken(self): ...

class TokenStreamHiddenTokenFilter(TokenStreamBasicFilter):
    hideMask: Any = ...
    nextMonitoredToken: Any = ...
    lastHiddenToken: Any = ...
    firstHidden: Any = ...
    def __init__(self, input: Any) -> None: ...
    def consume(self) -> None: ...
    def consumeFirst(self) -> None: ...
    def getDiscardMask(self): ...
    def getHiddenAfter(self, t: Any): ...
    def getHiddenBefore(self, t: Any): ...
    def getHideMask(self): ...
    def getInitialHiddenToken(self): ...
    def hide(self, m: Any) -> None: ...
    def LA(self, i: Any): ...
    def nextToken(self): ...

class StringBuffer:
    text: Any = ...
    def __init__(self, string: Optional[Any] = ...) -> None: ...
    def setLength(self, sz: Any) -> None: ...
    def length(self): ...
    def append(self, c: Any) -> None: ...
    def getString(self, a: Optional[Any] = ..., length: Optional[Any] = ...): ...
    toString: Any = ...

class Reader:
    cin: Any = ...
    buf: Any = ...
    def __init__(self, stream: Any) -> None: ...
    def read(self, num: Any): ...

class CharScanner(TokenStream):
    NO_CHAR: int = ...
    EOF_CHAR: str = ...
    saveConsumedInput: bool = ...
    tokenClass: Any = ...
    caseSensitive: bool = ...
    caseSensitiveLiterals: bool = ...
    literals: Any = ...
    tabsize: int = ...
    commitToPath: bool = ...
    traceDepth: int = ...
    text: Any = ...
    hashString: Any = ...
    def __init__(self, *argv: Any, **kwargs: Any) -> None: ...
    def __iter__(self): ...
    inputState: Any = ...
    def setInput(self, *argv: Any) -> None: ...
    def setTabSize(self, size: Any) -> None: ...
    def getTabSize(self): ...
    def setCaseSensitive(self, t: Any) -> None: ...
    def setCommitToPath(self, commit: Any) -> None: ...
    def setFilename(self, f: Any) -> None: ...
    def setLine(self, line: Any) -> None: ...
    def setText(self, s: Any) -> None: ...
    def getCaseSensitive(self): ...
    def getCaseSensitiveLiterals(self): ...
    def getColumn(self): ...
    def setColumn(self, c: Any) -> None: ...
    def getCommitToPath(self): ...
    def getFilename(self): ...
    def getInputBuffer(self): ...
    def getInputState(self): ...
    def setInputState(self, state: Any) -> None: ...
    def getLine(self): ...
    def getText(self): ...
    def getTokenObject(self): ...
    def LA(self, i: Any): ...
    def makeToken(self, type: Any): ...
    def mark(self): ...
    def match(self, item: Any): ...
    def matchNot(self, c: Any) -> None: ...
    def matchRange(self, c1: Any, c2: Any) -> None: ...
    def newline(self) -> None: ...
    def tab(self) -> None: ...
    def panic(self, s: str = ...) -> None: ...
    def reportError(self, s: Any) -> None: ...
    def reportWarning(self, s: Any) -> None: ...
    def resetText(self) -> None: ...
    def rewind(self, pos: Any) -> None: ...
    def setTokenObjectClass(self, cl: Any) -> None: ...
    def testForLiteral(self, token: Any): ...
    def testLiteralsTable(self, *args: Any): ...
    def toLower(self, c: Any): ...
    def traceIndent(self) -> None: ...
    def traceIn(self, rname: Any) -> None: ...
    def traceOut(self, rname: Any) -> None: ...
    def uponEOF(self) -> None: ...
    def append(self, c: Any) -> None: ...
    def commit(self) -> None: ...
    def consume(self) -> None: ...
    def consumeUntil_char(self, c: Any) -> None: ...
    def consumeUntil_bitset(self, bitset: Any) -> None: ...
    def default(self, la1: Any) -> None: ...
    def filterdefault(self, la1: Any, *args: Any) -> None: ...
    def raise_NoViableAlt(self, la1: Optional[Any] = ...) -> None: ...
    def set_return_token(self, _create: Any, _token: Any, _ttype: Any, _offset: Any): ...

class CharScannerIterator:
    inst: Any = ...
    def __init__(self, inst: Any) -> None: ...
    def next(self): ...

class BitSet:
    BITS: int = ...
    NIBBLE: int = ...
    LOG_BITS: int = ...
    MOD_MASK: Any = ...
    data: Any = ...
    def __init__(self, data: Optional[Any] = ...) -> None: ...
    def member(self, item: Any): ...
    def wordNumber(self, bit: Any): ...
    def bitMask(self, bit: Any): ...
    def set(self, bit: Any, on: bool = ...) -> None: ...
    add: Any = ...
    def off(self, bit: Any, off: bool = ...) -> None: ...
    def at(self, bit: Any): ...

def illegalarg_ex(func: Any) -> None: ...
def runtime_ex(func: Any) -> None: ...

class TokenBuffer:
    input: Any = ...
    nMarkers: int = ...
    markerOffset: int = ...
    numToConsume: int = ...
    queue: Any = ...
    def __init__(self, stream: Any) -> None: ...
    def reset(self) -> None: ...
    def consume(self) -> None: ...
    def fill(self, amount: Any) -> None: ...
    def getInput(self): ...
    def LA(self, k: Any): ...
    def LT(self, k: Any): ...
    def mark(self): ...
    def rewind(self, mark: Any) -> None: ...
    def syncConsume(self) -> None: ...

class ParserSharedInputState:
    input: Any = ...
    def __init__(self) -> None: ...
    guessing: int = ...
    filename: Any = ...
    def reset(self) -> None: ...

class Parser:
    tokenNames: Any = ...
    returnAST: Any = ...
    astFactory: Any = ...
    tokenTypeToASTClassMap: Any = ...
    ignoreInvalidDebugCalls: bool = ...
    traceDepth: int = ...
    inputState: Any = ...
    def __init__(self, *args: Any, **kwargs: Any) -> None: ...
    def getTokenTypeToASTClassMap(self): ...
    def addMessageListener(self, l: Any) -> None: ...
    def addParserListener(self, l: Any) -> None: ...
    def addParserMatchListener(self, l: Any) -> None: ...
    def addParserTokenListener(self, l: Any) -> None: ...
    def addSemanticPredicateListener(self, l: Any) -> None: ...
    def addSyntacticPredicateListener(self, l: Any) -> None: ...
    def addTraceListener(self, l: Any) -> None: ...
    def consume(self) -> None: ...
    def consumeUntil(self, arg: Any) -> None: ...
    def defaultDebuggingSetup(self) -> None: ...
    def getAST(self): ...
    def getASTFactory(self): ...
    def getFilename(self): ...
    def getInputState(self): ...
    def setInputState(self, state: Any) -> None: ...
    def getTokenName(self, num: Any): ...
    def getTokenNames(self): ...
    def isDebugMode(self): ...
    def LA(self, i: Any) -> None: ...
    def LT(self, i: Any) -> None: ...
    def mark(self): ...
    def match(self, set: Any) -> None: ...
    def matchNot(self, t: Any) -> None: ...
    def removeMessageListener(self, l: Any) -> None: ...
    def removeParserListener(self, l: Any) -> None: ...
    def removeParserMatchListener(self, l: Any) -> None: ...
    def removeParserTokenListener(self, l: Any) -> None: ...
    def removeSemanticPredicateListener(self, l: Any) -> None: ...
    def removeSyntacticPredicateListener(self, l: Any) -> None: ...
    def removeTraceListener(self, l: Any) -> None: ...
    def reportError(self, x: Any) -> None: ...
    def reportWarning(self, s: Any) -> None: ...
    def rewind(self, pos: Any) -> None: ...
    def setASTFactory(self, f: Any) -> None: ...
    def setASTNodeClass(self, cl: Any) -> None: ...
    def setASTNodeType(self, nodeType: Any) -> None: ...
    def setDebugMode(self, debugMode: Any) -> None: ...
    def setFilename(self, f: Any) -> None: ...
    def setIgnoreInvalidDebugCalls(self, value: Any) -> None: ...
    def setTokenBuffer(self, t: Any) -> None: ...
    def traceIndent(self) -> None: ...
    def traceIn(self, rname: Any) -> None: ...
    def traceOut(self, rname: Any) -> None: ...
    def addASTChild(self, currentAST: Any, child: Any) -> None: ...
    def makeASTRoot(self, currentAST: Any, root: Any) -> None: ...

class LLkParser(Parser):
    k: Any = ...
    def __init__(self, *args: Any, **kwargs: Any) -> None: ...
    def consume(self) -> None: ...
    def LA(self, i: Any): ...
    def LT(self, i: Any): ...
    def set_k(self, index: Any, *args: Any) -> None: ...
    def trace(self, ee: Any, rname: Any) -> None: ...
    def traceIn(self, rname: Any) -> None: ...
    def traceOut(self, rname: Any) -> None: ...

class TreeParserSharedInputState:
    guessing: int = ...
    def __init__(self) -> None: ...

class TreeParser:
    inputState: Any = ...
    tokenNames: Any = ...
    returnAST: Any = ...
    astFactory: Any = ...
    traceDepth: int = ...
    def __init__(self, *args: Any, **kwargs: Any) -> None: ...
    def getAST(self): ...
    def getASTFactory(self): ...
    def getTokenName(self, num: Any): ...
    def getTokenNames(self): ...
    def match(self, t: Any, set: Any) -> None: ...
    def matchNot(self, t: Any, ttype: Any) -> None: ...
    def reportError(self, ex: Any) -> None: ...
    def reportWarning(self, s: Any) -> None: ...
    def setASTFactory(self, f: Any) -> None: ...
    def setASTNodeType(self, nodeType: Any) -> None: ...
    def setASTNodeClass(self, nodeType: Any) -> None: ...
    def traceIndent(self) -> None: ...
    def traceIn(self, rname: Any, t: Any) -> None: ...
    def traceOut(self, rname: Any, t: Any) -> None: ...
    def addASTChild(self, currentAST: Any, child: Any) -> None: ...
    def makeASTRoot(self, currentAST: Any, root: Any) -> None: ...

def rightmost(ast: Any): ...
def cmptree(s: Any, t: Any, partial: Any): ...

class AST:
    def __init__(self) -> None: ...
    def addChild(self, c: Any) -> None: ...
    def equals(self, t: Any): ...
    def equalsList(self, t: Any): ...
    def equalsListPartial(self, t: Any): ...
    def equalsTree(self, t: Any): ...
    def equalsTreePartial(self, t: Any): ...
    def findAll(self, tree: Any) -> None: ...
    def findAllPartial(self, subtree: Any) -> None: ...
    def getFirstChild(self): ...
    def getNextSibling(self): ...
    def getText(self): ...
    def getType(self): ...
    def getLine(self): ...
    def getColumn(self): ...
    def getNumberOfChildren(self): ...
    def initialize(self, t: Any) -> None: ...
    def setFirstChild(self, c: Any) -> None: ...
    def setNextSibling(self, n: Any) -> None: ...
    def setText(self, text: Any) -> None: ...
    def setType(self, ttype: Any) -> None: ...
    def toString(self) -> None: ...
    def toStringList(self): ...
    def toStringTree(self): ...

class ASTNULLType(AST):
    def __init__(self) -> None: ...
    def getText(self): ...
    def getType(self): ...

class BaseAST(AST):
    verboseStringConversion: bool = ...
    tokenNames: Any = ...
    down: Any = ...
    right: Any = ...
    def __init__(self) -> None: ...
    def addChild(self, node: Any) -> None: ...
    def getNumberOfChildren(self): ...
    def doWorkForFindAll(self, v: Any, target: Any, partialMatch: Any) -> None: ...
    def equals(self, t: Any): ...
    def equalsList(self, t: Any): ...
    def equalsListPartial(self, t: Any): ...
    def equalsTree(self, t: Any): ...
    def equalsTreePartial(self, t: Any): ...
    def findAll(self, target: Any): ...
    def findAllPartial(self, sub: Any): ...
    def getFirstChild(self): ...
    def getNextSibling(self): ...
    def getText(self): ...
    def getType(self): ...
    def getLine(self): ...
    def getColumn(self): ...
    def removeChildren(self) -> None: ...
    def setFirstChild(self, c: Any) -> None: ...
    def setNextSibling(self, n: Any) -> None: ...
    def setText(self, text: Any) -> None: ...
    def setType(self, ttype: Any) -> None: ...
    def setVerboseStringConversion(verbose: Any, names: Any) -> None: ...
    def getTokenNames(self): ...
    def toString(self): ...
    def toStringList(self): ...
    def toStringTree(self): ...

class CommonAST(BaseAST):
    ttype: Any = ...
    text: str = ...
    line: int = ...
    column: int = ...
    def __init__(self, token: Optional[Any] = ...) -> None: ...
    def getText(self): ...
    def getType(self): ...
    def getLine(self): ...
    def getColumn(self): ...
    def initialize(self, *args: Any) -> None: ...
    def setText(self, text_: Any) -> None: ...
    def setType(self, ttype_: Any) -> None: ...

class CommonASTWithHiddenTokens(CommonAST):
    hiddenBefore: Any = ...
    hiddenAfter: Any = ...
    def __init__(self, *args: Any) -> None: ...
    def getHiddenAfter(self): ...
    def getHiddenBefore(self): ...
    def initialize(self, *args: Any) -> None: ...

class ASTPair:
    root: Any = ...
    child: Any = ...
    def __init__(self) -> None: ...
    def advanceChildToEnd(self) -> None: ...
    def copy(self): ...
    def toString(self): ...

class ASTFactory:
    def __init__(self, table: Optional[Any] = ...) -> None: ...
    def create(self, *args: Any): ...
    def setASTNodeClass(self, className: Optional[Any] = ...) -> None: ...
    setASTNodeType: Any = ...
    def getASTNodeClass(self): ...
    def getTokenTypeToASTClassMap(self): ...
    def setTokenTypeToASTClassMap(self, amap: Any) -> None: ...
    def error(self, e: Any) -> None: ...
    def setTokenTypeASTNodeType(self, tokenType: Any, className: Any) -> None: ...
    def getASTNodeType(self, tokenType: Any): ...
    def dup(self, t: Any): ...
    def dupList(self, t: Any): ...
    def dupTree(self, t: Any): ...
    maptype: Any = ...

class ASTVisitor:
    def __init__(self, *args: Any) -> None: ...
    def visit(self, ast: Any) -> None: ...

ASTNULL: Any

def make(*nodes: Any): ...
def dup(t: Any, factory: Any): ...
def dupList(t: Any, factory: Any): ...
def dupTree(t: Any, factory: Any): ...



"""
Support and convert several CAN (Controller Area Network) database formats .arxml .dbc .dbf .kcd .sym fibex xls(x) ...

Canmatrix implements a "Python Can Matrix Object" which describes the can-communication
and the needed objects (Boardunits, Frames, Signals, Values, ...) Canmatrix also includes
two Tools (canconvert and cancompare) for converting and comparing CAN databases.
There are also some extract and merge options for dealing with can databases.

**supported file formats for import:**

            .dbc candb / Vector

            .dbf Busmaster (open source!)

            .kcd kayak (open source!)

            .arxml autosar system description

            .yaml dump of the python object

            .xls(x) excel xls-import, works with .xls-file generated by this lib

            .sym peak pcan can description

**supported file formats for export:**

            .dbc

            .dbf

            .kcd

            .xls(x)

            .json Canard (open source!)

            .arxml (very basic implementation)

            .yaml (dump of the python object)

            .sym

            .xml (fibex)

"""

classifiers = """\
Development Status :: 4 - Beta
Environment :: Console
License :: OSI Approved :: BSD License
Topic :: Scientific/Engineering
Programming Language :: Python
Programming Language :: Python :: 2.7
Programming Language :: Python :: 3.4
Programming Language :: Python :: 3.5
Programming Language :: Python :: 3.6
Programming Language :: Python :: 3.7
"""

import sys
from setuptools import setup, find_packages
import versioneer

doclines = __doc__.split("\n")

setup(
    name = "canmatrix",
    version = versioneer.get_version(),
    cmdclass = versioneer.get_cmdclass(),
    maintainer = "Eduard Broecker",
    maintainer_email = "eduard@gmx.de",
    url = "http://github.com/ebroecker/canmatrix",
    classifiers = filter(None, classifiers.split("\n")),
    description = doclines[0],
    keywords = "CAN dbc arxml kcd dbf sym",
    long_description = "\n".join(doclines[2:]),
    license = "BSD",
    platforms = ["any"],
      install_requires = [
        "attrs>=18.1.0",
        "bitstruct",
        "click",
        "future",
        "pathlib2",
        "typing; python_version < '3.5'",
    ],
    extras_require = {
        "arxml": ["lxml"],
        "kcd": ["lxml"],
        "fibex": ["lxml"],
        "xls": ["xlrd", "xlwt"],
        "xlsx": ["xlsxwriter"],
        "yaml": ["pyyaml"],
        "dbc": [],
        "dbf": [],
        "json": [],
        "sym": [],
        "test": ["coverage", "pytest", "pytest-cov", "tox"],
    },

    packages = find_packages("src"),
    package_dir = {"": "src"},
    package_data = {"canmatrix" : ["tests/*.dbc", "tests/*.arxml", "j1939.dbc"]},
    entry_points={'console_scripts': ['cancompare = canmatrix.cli.compare:cli_compare',
                                      'canconvert = canmatrix.cli.convert:cli_convert']}
)




# Stubs for xlwt.Cell (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

class StrCell:
    rowx: Any = ...
    colx: Any = ...
    xf_idx: Any = ...
    sst_idx: Any = ...
    def __init__(self, rowx: Any, colx: Any, xf_idx: Any, sst_idx: Any) -> None: ...
    def get_biff_data(self): ...

class BlankCell:
    rowx: Any = ...
    colx: Any = ...
    xf_idx: Any = ...
    def __init__(self, rowx: Any, colx: Any, xf_idx: Any) -> None: ...
    def get_biff_data(self): ...

class MulBlankCell:
    rowx: Any = ...
    colx1: Any = ...
    colx2: Any = ...
    xf_idx: Any = ...
    def __init__(self, rowx: Any, colx1: Any, colx2: Any, xf_idx: Any) -> None: ...
    def get_biff_data(self): ...

class NumberCell:
    rowx: Any = ...
    colx: Any = ...
    xf_idx: Any = ...
    number: Any = ...
    def __init__(self, rowx: Any, colx: Any, xf_idx: Any, number: Any) -> None: ...
    def get_encoded_data(self): ...
    def get_biff_data(self): ...

class BooleanCell:
    rowx: Any = ...
    colx: Any = ...
    xf_idx: Any = ...
    number: Any = ...
    def __init__(self, rowx: Any, colx: Any, xf_idx: Any, number: Any) -> None: ...
    def get_biff_data(self): ...

error_code_map: Any

class ErrorCell:
    rowx: Any = ...
    colx: Any = ...
    xf_idx: Any = ...
    number: Any = ...
    def __init__(self, rowx: Any, colx: Any, xf_idx: Any, error_string_or_code: Any) -> None: ...
    def get_biff_data(self): ...

class FormulaCell:
    rowx: Any = ...
    colx: Any = ...
    xf_idx: Any = ...
    frmla: Any = ...
    calc_flags: Any = ...
    def __init__(self, rowx: Any, colx: Any, xf_idx: Any, frmla: Any, calc_flags: int = ...) -> None: ...
    def get_biff_data(self): ...



# Stubs for xlwt.Bitmap (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from .BIFFRecords import BiffRecord
from typing import Any

class ObjBmpRecord(BiffRecord):
    def __init__(self, row: Any, col: Any, sheet: Any, im_data_bmp: Any, x: Any, y: Any, scale_x: Any, scale_y: Any) -> None: ...

class ImRawDataBmpRecord(BiffRecord):
    def __init__(self, data: Any) -> None: ...

class ImDataBmpRecord(ImRawDataBmpRecord):
    def __init__(self, filename: Any) -> None: ...
